@@ -1,4 +1,8 @@
-class genome:
+"""
+"""
+
+class Genome:
+    """Optional wrapper for genomes, so that they can be printed/operated on in a more pythonic way."""
     def __init__(self, framework, genome):
         self.framework = framework
         self.generating_object = genome
